==> stargazer_4.5.3.tar.gz: stargazer/man/stargazer_acknowledge.Rd <==
\name{stargazer_acknowledge}
\alias{stargazer package acknowledgments}

%- Also NEED an '\alias' for EACH other topic documented here.
\title{Acknowledgments}
%%  ~~function to do ... ~~
\description{
%%  ~~ A concise (1-5 lines) description of what the function does. ~~
I would like to thank everyone who has tested this package, or provided useful suggestions. I am especially grateful to the following people, listed in alphabetical order (based on last names):
}

\section{Thank you:}{
Ross Ahmed, Newcastle University, UK\cr
Liviu Andronic, University of Toulouse, France\cr
Erin Baggott, Harvard University, USA\cr
Eva Bernauer, University of Mannheim, Germany\cr
Ruben de Bliek, Erasmus University Rotterdam, Netherlands\cr
Julian Chan, Boston University, USA\cr
Volha Charnych, Harvard University, USA\cr
John Coglianese, Harvard University, USA\cr
Brandon de la Cuesta, Princeton University, USA\cr
Sebastian Daza, University of Wisconsin-Madison, USA\cr
Bryan Dettrey, Pennsylvania State University, USA \cr
Stefan Dimitriadis, Harvard University, USA\cr
Gregory Eady, University of Toronto, Canada\cr
Andrey Fradkin, Stanford University, USA\cr
Bernard Fraga, Harvard University, USA\cr
Tal Galili, Tel Aviv University, Israel\cr
Cheng Gao, Harvard University, USA\cr
Charlie Gibbons, University of California-Berkeley, USA\cr
Rebecca Goldstein, Harvard University, USA\cr
Josiah Grover, Ball State University, USA\cr
Rasmus Hertzum, Glostrup University Hospital, Denmark\cr
Gregor Hochschild, Germany \cr
Christian Horea, University of Heidelberg, Germany \cr
Connor Huff, Harvard University, USA\cr
Melissa Kline, Massachussetts Institute of Technology, USA\cr
Maxim Kovalenko, University of Antwerp, Belgium\cr
Johannes Kutsam, Johann Kepler University, Linz, Austria \cr
Michal Kvasnicka, Masaryk University, Brno, Czech Republic \cr
Akos Lada, Harvard University, USA\cr
Yphtach Lelkes, University of Amsterdam, Netherlands\cr
Carl Jacob Liebersohn, Massachussetts Institute of Technology, USA\cr
Daniel Yew Mao Lim, Harvard University, USA\cr
Eric Lin, Harvard University, USA \cr
Christopher Lucas, Harvard University, USA\cr
Richard Martin, University of Victoria, Canada \cr
Tamim Mohammad, University of Massachussetts-Boston, USA\cr
Christoph Nguyen, Northwestern University, USA\cr
Dominic Nyhuis, University of Mannheim, Germany \cr
Stephen Pettigrew, Harvard University, USA\cr
Giuseppe Ragusa, Luiss University, Rome, Italy\cr
Christoph Riedl, Northeastern University, USA\cr
Francesco Sarracino, STATEC, Luxembourg\cr
Martijn Schoonvelde, University of Exeter, United Kingdom \cr
Jason Sclar, Harvard University, USA\cr
Jennifer Sheehy-Skeffington, Harvard University, USA\cr
Boris Shor, University of Chicago, USA\cr
Emily Stephen, Boston University, USA\cr
Beth Truesdale, Harvard University, USA\cr
Anna Weisfeiler, University of Wisconsin-Madison, USA\cr
Carl Witthoft, UTC Aerospace Systems, USA \cr
Jan Zilinsky, University of Chicago, USA\cr
Steffen Zittlau, University of Mannheim, Germany\cr
}

% Add one or more standard keywords, see file 'KEYWORDS' in the
% R documentation directory.
\keyword{ package }
\keyword{ models }
\keyword{ regression }
\keyword{ nonlinear }
\keyword{ univar }
\keyword{ interface }
\keyword{ programming }
\keyword{ IO }% __ONLY ONE__ keyword per line

==> stargazer_5.0.tar.gz: stargazer/man/stargazer_acknowledge.Rd <==
\name{stargazer_acknowledge}
\alias{stargazer package acknowledgments}

%- Also NEED an '\alias' for EACH other topic documented here.
\title{Acknowledgments}
%%  ~~function to do ... ~~
\description{
%%  ~~ A concise (1-5 lines) description of what the function does. ~~
I would like to thank everyone who has tested this package, or provided useful suggestions. I am especially grateful to the following people, listed in alphabetical order (based on last names):
}

\section{Thank you:}{
Ross Ahmed, Newcastle University, UK\cr
Liviu Andronic, University of Toulouse, France\cr
Erin Baggott, Harvard University, USA\cr
Rodrigo Belo, Carnegie Mellon University, USA\cr
Eva Bernauer, University of Mannheim, Germany\cr
Ruben de Bliek, Erasmus University Rotterdam, Netherlands\cr
Julian Chan, Boston University, USA\cr
Dana Chandler, Massachussetts Institute of Technology, USA \cr
Volha Charnych, Harvard University, USA\cr
John Coglianese, Harvard University, USA\cr
Brandon de la Cuesta, Princeton University, USA\cr
Sebastian Daza, University of Wisconsin-Madison, USA\cr
Bryan Dettrey, Pennsylvania State University, USA \cr
Stefan Dimitriadis, Harvard University, USA\cr
Gregory Eady, University of Toronto, Canada\cr
Thiemo Fetzer, London School of Economics, UK \cr
Andrey Fradkin, Stanford University, USA\cr
Bernard Fraga, Harvard University, USA\cr
Tal Galili, Tel Aviv University, Israel\cr
Cheng Gao, Harvard University, USA\cr
Charlie Gibbons, University of California-Berkeley, USA\cr
Rebecca Goldstein, Harvard University, USA\cr
Josiah Grover, Ball State University, USA\cr
Rasmus Hertzum, Glostrup University Hospital, Denmark\cr
Gregor Hochschild, Germany \cr
Christian Horea, University of Heidelberg, Germany \cr
Connor Huff, Harvard University, USA\cr
Nicole Janz, University of Cambridge, UK\cr
Melissa Kline, Massachussetts Institute of Technology, USA\cr
Maxim Kovalenko, University of Antwerp, Belgium\cr
Johannes Kutsam, Johann Kepler University, Linz, Austria \cr
Michal Kvasnicka, Masaryk University, Brno, Czech Republic \cr
Akos Lada, Harvard University, USA\cr
Christopher Lee, McGill University, Canada\cr
Yphtach Lelkes, University of Amsterdam, Netherlands\cr
Carl Jacob Liebersohn, Massachussetts Institute of Technology, USA\cr
Daniel Yew Mao Lim, Harvard University, USA\cr
Eric Lin, Harvard University, USA \cr
Christopher Lucas, Harvard University, USA\cr
Jochen Luedering, University of Giessen, Germany\cr
Richard Martin, University of Victoria, Canada \cr
Tamim Mohammad, University of Massachussetts-Boston, USA\cr
Samuel Moy, The Brattle Group, USA\cr
Christoph Nguyen, Northwestern University, USA\cr
Dominic Nyhuis, University of Mannheim, Germany \cr
Suhas D. Parandekar, The World Bank\cr
Nathan Paxton, American University, USA\cr
Stephen Pettigrew, Harvard University, USA\cr
Giuseppe Ragusa, Luiss University, Rome, Italy\cr
Christoph Riedl, Northeastern University, USA\cr
Francesco Sarracino, STATEC, Luxembourg\cr
Martijn Schoonvelde, University of Exeter, United Kingdom \cr
Jason Sclar, Harvard University, USA\cr
Jennifer Sheehy-Skeffington, Harvard University, USA\cr
Boris Shor, University of Chicago, USA\cr
Zachary Steinert-Threkeld, University of California-San Diego, USA\cr
Emily Stephen, Boston University, USA\cr
Bryan Stroube, University of Maryland, USA\cr
Beth Truesdale, Harvard University, USA\cr
Anna Weisfeiler, University of Wisconsin-Madison, USA\cr
Carl Witthoft, UTC Aerospace Systems, USA \cr
Jan Zilinsky, University of Chicago, USA\cr
Steffen Zittlau, University of Mannheim, Germany\cr
}

% Add one or more standard keywords, see file 'KEYWORDS' in the
% R documentation directory.
\keyword{ package }
\keyword{ models }
\keyword{ regression }
\keyword{ nonlinear }
\keyword{ univar }
\keyword{ interface }
\keyword{ programming }
\keyword{ IO }% __ONLY ONE__ keyword per line
